@@ -31,6 +31,7 @@ import math
 import cmath
 import random
 import requests
+import time
 
 
 # Globals {{{1
@@ -254,7 +255,7 @@ reciprocal = UnaryOp(
 )
 reciprocal.addTest(stimulus="4 recip", result=1 / 4, units="", text="250m")
 reciprocal.addTest(stimulus="1kOhm recip", result=1 / 1000, units="", text="1m")
-reciprocal.addTest(stimulus="0 recip", error="division by zero.\n0 recip\n  ↑")
+reciprocal.addTest(stimulus="0 recip", error="division by zero.\n0 recip\n  △")
 reciprocal.addTest(stimulus="j recip", result=-1j, units="", text="-j")
 
 # ceiling {{{3
@@ -275,7 +276,7 @@ ceiling.addTest(stimulus="-1.5 ceil", result=math.ceil(-1.5), units="", text="-1
 ceiling.addTest(stimulus="7.5_Hz ceil", result=math.ceil(7.5), units="Hz", text="8 Hz")
 ceiling.addTest(
     stimulus="j ceil",
-    error="Function does not support a complex argument.\nj ceil\n  ↑",
+    error="must be real number, not complex.\nj ceil\n  △",
 )
 
 # floor {{{3
@@ -296,7 +297,7 @@ floor.addTest(stimulus="-1.5 floor", result=math.floor(-1.5), units="", text="-2
 floor.addTest(stimulus="7.5_Hz floor", result=math.floor(7.5), units="Hz", text="7 Hz")
 floor.addTest(
     stimulus="j floor",
-    error="Function does not support a complex argument.\nj floor\n  ↑",
+    error="must be real number, not complex.\nj floor\n  △",
 )
 
 
@@ -565,7 +566,7 @@ arcSine.addTest(stimulus="1 asin", result=90, units="degs", text="90 degs")
 arcSine.addTest(stimulus="rads 1 sin asin", result=1, units="rads", text="1 rads")
 arcSine.addTest(stimulus="degs -1 asin", result=-90, units="degs", text="-90 degs")
 arcSine.addTest(
-    stimulus="degs 2 asin", error="math domain error.\ndegs 2 asin\n       ↑"
+    stimulus="degs 2 asin", error="math domain error.\ndegs 2 asin\n       △"
 )
 
 # arc cosine {{{3
@@ -584,7 +585,7 @@ arcCosine.addTest(stimulus="0 acos", result=90, units="degs", text="90 degs")
 arcCosine.addTest(stimulus="rads 1 acos", result=0, units="rads", text="0 rads")
 arcCosine.addTest(stimulus="degs 45 cos acos", result=45, units="degs", text="45 degs")
 arcCosine.addTest(
-    stimulus="degs 2 acos", error="math domain error.\ndegs 2 acos\n       ↑"
+    stimulus="degs 2 acos", error="math domain error.\ndegs 2 acos\n       △"
 )
 
 # arc tangent {{{3
@@ -2346,7 +2347,7 @@ setUnits.addTest(
 convertUnits = Convert(
     ">",
     description = ">«#⟪units⟫»: convert value to given units",
-    synopsis = "#⟪x⟫, ... → #⟪x⟫ converted to new desired units, ...",
+    synopsis = "#⟪x⟫, ... → #⟪x⟫ converted to specified units, ...",
     summary = """
         The value in the #⟪x⟫ is popped from the stack, converted to the desired
         units, and pushed back on to the stack.
@@ -2379,9 +2380,9 @@ describeFunctions = Command(
     name = "functions",
     key = "(",
     action = Calculator.describeFunctions,
-    description = "(…)«name»: a user-defined function or macro.",
+    description = "(...)«name»: a user-defined function or macro.",
     summary = """
-        A function is defined with the name «name» where … is a list of commands.
+        A function is defined with the name «name» where ... is a list of commands.
         When «name» is entered as a command, it is replaced by the list of
         commands.
     """,
@@ -2710,11 +2711,20 @@ chemistryActions = (
 # get the current bitcoin price from coingecko.com
 url = 'https://api.coingecko.com/api/v3/simple/price'
 params = dict(ids='bitcoin', vs_currencies='usd')
+last_btc_update = None
+btc_price = None
+btc_price_ttl = 60
 def get_btc_price():
+    global last_btc_update, btc_price
+    current_time = time.monotonic()
     try:
-        resp = requests.get(url=url, params=params)
-        prices = resp.json()
-        return prices['bitcoin']['usd']
+        if last_btc_update is None or current_time - last_btc_update > btc_price_ttl:
+            # get the current price of BTC and cache it
+            resp = requests.get(url=url, params=params)
+            last_btc_update = current_time
+            prices = resp.json()
+            btc_price = prices['bitcoin']['usd']
+        return btc_price
     except Exception as e:
         raise Error('cannot connect to coingecko.com.')
 
