@@ -15,8 +15,8 @@ import re
 import sys
 
 # Set the version information {{{1
-__version__ = "1.9.0"
-__released__ = "2022-01-04"
+__version__ = "1.10"
+__released__ = "2022-12-27"
 
 # Utility functions {{{1
 italicsRegex = re.compile(r"#⟪(\w+)⟫")
@@ -1543,7 +1543,7 @@ class Calculator:
         def showLoc(given, index):
             cmds = " ".join(given)
             okay = " ".join(given[:index])
-            return "\n" + cmds + "\n " + " " * len(okay) + "↑"
+            return "\n" + cmds + "\n " + " " * len(okay) + "△"
 
         if self.backUpStack:
             self.prevStack = self.stack.clone()
@@ -1590,7 +1590,7 @@ class Calculator:
         except TypeError as e:
             if str(e).startswith("can't convert complex to float"):
                 raise CalculatorError(
-                    "Function does not support a complex argument."
+                    "must be real number, not complex."
                     + showLoc(given, index)
                 )
             else:
